BranchUserModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'branch_user', primaryKeys: ['branch_id', 'user_id'], foreignKeys: [ForeignKey(childColumns: ['role_id'], parentColumns: ['id'], entity: UserRoleModel), ForeignKey(childColumns: ['user_id'], parentColumns: ['id'], entity: UserModel), ForeignKey(childColumns: ['branch_id'], parentColumns: ['id'], entity: BranchModel)])

Constructors

BranchUserModel({required int branchId, required int roleId, bool status = false})
const
BranchUserModel.fromMap(Map<String, dynamic> map)

Properties

branchId → int
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
primary key
no setter
roleId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
status → bool
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

branchIdTag → const String
roleIdTag → const String
sessionIdTag → const String
statusTag → const String
userIdTag → const String