DeviceFilter class

Inheritance

Constructors

DeviceFilter({InWhere<String>? ids, InWhere<bool>? status})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
final

Methods

check(DeviceModel element) → bool
override
copyWith({InWhere<String>? ids, InWhere<bool>? status}) → DeviceFilter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited