SessionModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'session', primaryKeys: ['id'], foreignKeys: [ForeignKey(childColumns: ['device_id'], parentColumns: ['id'], entity: DeviceModel), ForeignKey(childColumns: ['user_id'], parentColumns: ['id'], entity: UserModel)])

Constructors

SessionModel({int id = 0, bool status = true, String deviceId = "", String userId = ""})
SessionModel.fromMap(Map<String, dynamic> map)

Properties

deviceId → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
lastUseAt → DateTime
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → DateTime
final
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

deviceIdTag → const String
lastUseAtTag → const String
startAtTag → const String
userIdTag → const String