UserModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'user', primaryKeys: ['id'])

Constructors

UserModel({int id = 0, required String name})
UserModel.fromMap(Map<String, dynamic> map)

Properties

createAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
name → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

createAtTag → const String
nameTag → const String
sessionIdTag → const String