IdentityFilter<ModelType extends IdentityModel> class abstract

Inheritance
Implementers

Constructors

IdentityFilter({InWhere<int>? ids})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

check(ModelType element) → bool
override
copyWith({InWhere<int>? ids}) → IdentityFilter<IdentityModel>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited