InWhere<DataType> class

Constructors

InWhere({required Iterable<DataType> values, bool not = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
not → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<DataType>
final

Methods

check(DataType? field) → bool
checkStartWith(DataType? field) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited