LikeWhere class

Constructors

LikeWhere({required String value, bool contains = true, bool not = false})

Properties

contains → bool
final
hashCode → int
The hash code for this object.
no setterinherited
not → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

check(String? field, {bool contains = false}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited