NameFilter<ModelType extends NameModel> class abstract

Inheritance
Implementers

Constructors

NameFilter({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
finalinherited
text → LikeWhere?
final

Methods

check(ModelType element) → bool
override
copyWith({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text}) → NameFilter<NameModel>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCheck(ModelType element) → bool
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited