NameModel class abstract

Inheritance
Implementers

Constructors

NameModel({required int id, bool status = true, required String name})
const
NameModel.fromMap(Map<String, dynamic> map)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
name → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

nameTag → const String