AccountDbSet class abstract

Inheritance
Annotations
  • @dao

Constructors

AccountDbSet()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteRow(AccountModel row) → Future<void>
inherited
deleteRows(List<AccountModel> rows) → Future<int>
inherited
insertRow(AccountModel row) → Future<void>
inherited
insertRows(List<AccountModel> rows) → Future<List<int>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateRow(AccountModel row) → Future<void>
inherited
updateRows(List<AccountModel> rows) → Future<int>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited