AccountFilter class

Inheritance

Constructors

AccountFilter({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int>? branchIds, InWhere<int>? typeIds, InWhere<int>? levelIds, InWhere<int>? groupIds, InWhere<int>? upIds, InWhere<int>? userIds})
const

Properties

branchIds → InWhere<int>?
final
groupIds → InWhere<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
finalinherited
levelIds → InWhere<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
finalinherited
text → LikeWhere?
finalinherited
typeIds → InWhere<int>?
final
upIds → InWhere<int>?
final
userIds → InWhere<int>?
final

Methods

check(AccountModel element) → bool
override
copyWith({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int>? branchIds, InWhere<int>? typeIds, InWhere<int>? levelIds, InWhere<int>? groupIds, InWhere<int>? upIds, InWhere<int>? userIds}) → AccountFilter
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCheck(AccountModel element) → bool
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited