AccountGroupModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'account_group', primaryKeys: ['id'], foreignKeys: [ForeignKey(childColumns: ['up_id'], parentColumns: ['id'], entity: AccountGroupModel)])

Constructors

AccountGroupModel({int id = 0, required String name, bool status = true, String? description, int? upId})
const
AccountGroupModel.fromMap(Map<String, dynamic> map)

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
upId → int?
final
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

descriptionTag → const String
sessionIdTag → const String
upIdTag → const String
userIdTag → const String