AccountLevelApiController class

Inheritance

Constructors

AccountLevelApiController({required Dio dio, required AccountLevelDbSet dbSet, Set<AccountLevelModel> rows = const {}, String name = "AccountLevels"})

Properties

dbSet → AccountLevelDbSet
finalinherited
dio → Dio
finalinherited
fromMap → AccountLevelModel Function(Map<String, dynamic> data)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
rows → Set<AccountLevelModel>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(Map<String, Object> primaryKeys, {Options? options, CancelToken? cancelToken, bool caching = false}) → Future<AccountLevelModel?>
inherited
get({Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken, void onReceiveProgress(int total, int finish)?, bool caching = false}) → Future<List<AccountLevelModel>>
inherited
getById(Object id, {Options? options, CancelToken? cancelToken, void onReceiveProgress(int total, int finish)?, bool caching = false}) → Future<AccountLevelModel?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathBuild([String? methodPath]) → String
inherited
post(Map<String, dynamic> data, {Options? options, CancelToken? cancelToken, void onReceiveProgress(int total, int finish)?, void onSendProgress(int total, int finish)?, bool caching = false}) → Future<AccountLevelModel?>
inherited
put(Map<String, Object> primaryKeys, Map<String, dynamic> data, {Options? options, CancelToken? cancelToken, void onReceiveProgress(int total, int finish)?, void onSendProgress(int total, int finish)?, bool caching = false}) → Future<AccountLevelModel?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AccountLevelApiController?
getter/setter pair