AccountLevelFilter class

Inheritance

Constructors

AccountLevelFilter({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
finalinherited
text → LikeWhere?
finalinherited

Methods

check(AccountLevelModel element) → bool
inherited
copyWith({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text}) → AccountLevelFilter
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCheck(AccountLevelModel element) → bool
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited