AccountLevelModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'account_level', primaryKeys: ['id'], foreignKeys: [ForeignKey(childColumns: ['up_id'], parentColumns: ['id'], entity: AccountLevelModel)])

Constructors

AccountLevelModel({int id = 0, required String name, bool status = true, String? description, int? upId, int bits = 1})
const
AccountLevelModel.fromMap(Map<String, dynamic> map)

Properties

count → int
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
upId → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

countTag → const String
descriptionTag → const String
upIdTag → const String