AccountModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'account', primaryKeys: ['branch_id', 'id'], foreignKeys: [ForeignKey(childColumns: ['branch_id'], parentColumns: ['id'], entity: BranchModel), ForeignKey(childColumns: ['type_id'], parentColumns: ['id'], entity: AccountTypeModel), ForeignKey(childColumns: ['level_id'], parentColumns: ['id'], entity: AccountLevelModel), ForeignKey(childColumns: ['group_id'], parentColumns: ['id'], entity: AccountGroupModel), ForeignKey(childColumns: ['up_id'], parentColumns: ['id'], entity: AccountModel)])

Constructors

AccountModel({int id = 0, required String name, bool status = true, String? description, required int branchId, required int typeId, required int levelId, int? upId, int? groupId})
const
AccountModel.fromMap(Map<String, dynamic> map)

Properties

branchId → int
final
description → String?
final
groupId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
levelId → int
final
name → String
finalinherited
props → List<Object?>
primary key
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
typeId → int
final
upId → int?
final
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

branchIdTag → const String
descriptionTag → const String
groupIdTag → const String
levelIdTag → const String
sessionIdTag → const String
typeIdTag → const String
upIdTag → const String
userIdTag → const String