MeasureUnitFilter class

Inheritance

Constructors

MeasureUnitFilter({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int?>? upIds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
finalinherited
text → LikeWhere?
finalinherited
upIds → InWhere<int?>?
final

Methods

check(MeasureUnitModel element) → bool
override
copyWith({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int?>? upIds}) → MeasureUnitFilter
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCheck(MeasureUnitModel element) → bool
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited