ProductMeasureModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'product_measure', primaryKeys: ['product_id', 'currency_id', 'measure_unit_id'], foreignKeys: [ForeignKey(childColumns: ['product_id'], parentColumns: ['id'], entity: ProductModel), ForeignKey(childColumns: ['currency_id'], parentColumns: ['id'], entity: CurrencyModel), ForeignKey(childColumns: ['measure_unit_id'], parentColumns: ['id'], entity: MeasureUnitModel)])

Constructors

ProductMeasureModel({required int productId, required int measureUnitId, required int currencyId, required double price, bool status = true, String? barcode, int minCount = 1, int? maxCount, int? notifyCount})
const
ProductMeasureModel.fromMap(Map<String, dynamic> map)

Properties

barcode → String?
final
currencyId → int
final
hashCode → int
The hash code for this object.
no setterinherited
maxCount → int?
final
measureUnitId → int
final
minCount → int
final
notifyCount → int?
final
price → double
final
productId → int
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
status → bool
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

barcodeTag → const String
currencyIdTag → const String
maxCountTag → const String
measureUnitIdTag → const String
minCountTag → const String
notifyCountTag → const String
priceTag → const String
productIdTag → const String
sessionIdTag → const String
statusTag → const String
userIdTag → const String