ProductModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'product', primaryKeys: ['id'], foreignKeys: [ForeignKey(childColumns: ['catagory_id'], parentColumns: ['id'], entity: ProductCatagoryModel), ForeignKey(childColumns: ['type_id'], parentColumns: ['id'], entity: ProductTypeModel), ForeignKey(childColumns: ['measure_unit_id'], parentColumns: ['id'], entity: MeasureUnitModel)])

Constructors

ProductModel({int id = 0, required String name, bool status = true, required int catagoryId, required int typeId, int? measureUnitId, String? description, List<String>? images, String? secondName, bool hasExpireDate = false, int? ageDays})
const
ProductModel.fromMap(Map<String, dynamic> map)

Properties

ageDays → int?
final
catagoryId → int
final
description → String?
final
hasExpireDate → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
images → List<String>?
final
measureUnitId → int?
final
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondName → String?
final
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
typeId → int
final
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ageDaysTag → const String
catagoryIdTag → const String
descriptionTag → const String
hasExpireDateTag → const String
imagesTag → const String
measureUnitIdTag → const String
secondNameTag → const String
typeIdTag → const String
userIdTag → const String