ProductStorageModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'product_storage', primaryKeys: ['branch_id', 'store_id', 'product_id', 'measure_unit_id', 'currency_id', 'price', 'expired_at'], foreignKeys: [ForeignKey(childColumns: ['branch_id'], parentColumns: ['id'], entity: BranchModel), ForeignKey(childColumns: ['store_id'], parentColumns: ['id'], entity: StoreModel), ForeignKey(childColumns: ['product_id'], parentColumns: ['id'], entity: ProductModel), ForeignKey(childColumns: ['measure_unit_id'], parentColumns: ['id'], entity: MeasureUnitModel), ForeignKey(childColumns: ['currency_id'], parentColumns: ['id'], entity: CurrencyModel)])

Constructors

ProductStorageModel({required int branchId, required int productId, required int measureUnitId, required int currencyId, required int storeId, required double price, required DateTime expiredAt, DateTime? producedAt, required int count})
const
ProductStorageModel.fromMap(Map<String, dynamic> map)

Properties

branchId → int
final
count → int
final
currencyId → int
final
expiredAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
measureUnitId → int
final
price → double
final
producedAt → DateTime?
final
productId → int
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeId → int
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

branchIdTag → const String
countTag → const String
currencyIdTag → const String
expiredAtTag → const String
measureUnitIdTag → const String
priceTag → const String
producedAtTag → const String
productIdTag → const String
storeIdTag → const String