ReceiptModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'receipt', primaryKeys: ['branch_id', 'type_id', 'id'], foreignKeys: [ForeignKey(childColumns: ['branch_id'], parentColumns: ['id'], entity: BranchModel), ForeignKey(childColumns: ['type_id'], parentColumns: ['id'], entity: ReceiptTypeModel)])

Constructors

ReceiptModel({int id = 0, bool status = true, String? description, required int branchId, int? serialNo, required int typeId})
ReceiptModel.fromMap(Map<String, dynamic> map)

Properties

branchId → int
final
createAt → DateTime
final
description → String?
final
globalNo → int
uniuqe number generated auto
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
props → List<Object?>
primary key
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNo → int?
final
sessionId → int
final
status → bool
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
typeId → int
final
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

branchIdTag → const String
createAtTag → const String
descriptionTag → const String
globalNoTag → const String
serialNoTag → const String
sessionIdTag → const String
statusTag → const String
typeIdTag → const String
userIdTag → const String