StoreFilter class

Inheritance

Constructors

StoreFilter({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int>? branchIds})
const

Properties

branchIds → InWhere<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
ids → InWhere<int>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → InWhere<bool>?
finalinherited
text → LikeWhere?
finalinherited

Methods

check(StoreModel element) → bool
inherited
copyWith({InWhere<int>? ids, InWhere<bool>? status, LikeWhere? text, InWhere<int>? branchIds}) → StoreFilter
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCheck(StoreModel element) → bool
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited