StoreModel class

Inheritance
Annotations
  • @Entity.new(tableName: 'person', primaryKeys: ['id', 'branchId'], foreignKeys: [ForeignKey(childColumns: ['branch_id'], parentColumns: ['id'], entity: BranchModel)])

Constructors

StoreModel({int id = 0, required String name, bool status = true, String? description, required int branchId})
const
StoreModel.fromMap(Map<String, dynamic> map)

Properties

branchId → int
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

branchIdTag → const String
descriptionTag → const String
userIdTag → const String